@@ -1,4 +1,4 @@
-/* $Header: /home/hyperion/mu/christos/src/sys/tcsh-6.00/RCS/ed.init.c,v 3.2 1991/07/15 19:37:24 christos Exp $ */
+/* $Header: /home/hyperion/mu/christos/src/sys/tcsh-6.00/RCS/ed.init.c,v 3.9 1991/08/06 01:45:29 christos Exp $ */
 /*
  * ed.init.c: Editor initializations
  */
@@ -35,7 +35,7 @@
  * SUCH DAMAGE.
  */
 #include "config.h"
-RCSID("$Id: ed.init.c,v 3.2 1991/07/15 19:37:24 christos Exp $")
+RCSID("$Id: ed.init.c,v 3.9 1991/08/06 01:45:29 christos Exp $")
 
 #include "sh.h"
 #define EXTERN			/* intern */
@@ -49,75 +49,86 @@ RCSID("$Id: ed.init.c,v 3.2 1991/07/15 19:37:24 christos Exp $")
  */
 # if defined(VWERSE) && !defined(VWERASE)
 #  define VWERASE VWERSE
-# endif				/* VWERSE && !VWERASE */
+# endif /* VWERSE && !VWERASE */
 
 # if defined(VDISCRD) && !defined(VDISCARD)
 #  define VDISCARD VDISCRD
-# endif				/* VDISCRD && !VDISCARD */
+# endif /* VDISCRD && !VDISCARD */
+
+# if defined(VFLUSHO) && !defined(VDISCARD)
+#  define VDISCARD VFLUSHO
+# endif  /* VFLUSHO && VDISCARD */
 
 # if defined(VSTRT) && !defined(VSTART)
 #  define VSTART VSTRT
-# endif				/* VSTRT && ! VSTART */
+# endif /* VSTRT && ! VSTART */
 
 # if defined(VSTAT) && !defined(VSTATUS)
 #  define VSTATUS VSTAT
-# endif				/* VSTAT && ! VSTATUS */
+# endif /* VSTAT && ! VSTATUS */
 
 # ifndef ONLRET
 #  define ONLRET 0
-# endif				/* ONLRET */
+# endif /* ONLRET */
 
 # ifndef TAB3
 #  ifdef OXTABS
 #   define TAB3 OXTABS
 #  else
 #   define TAB3 0
-#  endif				/* OXTABS */
-# endif				/* !TAB3 */
+#  endif /* OXTABS */
+# endif /* !TAB3 */
+
+# if defined(OXTABS) && !defined(XTABS)
+#  define XTABS OXTABS
+# endif /* OXTABS && !XTABS */
 
 # ifndef ONLCR
 #  define ONLCR 0
-# endif				/* ONLCR */
+# endif /* ONLCR */
 
 # ifndef IEXTEN
 #  define IEXTEN 0
-# endif				/* IEXTEN */
+# endif /* IEXTEN */
 
 # ifndef ECHOCTL
 #  define ECHOCTL 0
-# endif				/* ECHOCTL */
+# endif /* ECHOCTL */
 
 # ifndef PARENB
 #  define PARENB 0
-# endif				/* PARENB */
+# endif /* PARENB */
 
 # ifndef EXTPROC
 #  define EXTPROC 0
-# endif				/* EXTPROC */
+# endif /* EXTPROC */
 
 # ifndef FLUSHO
 #  define FLUSHO  0
-# endif				/* FLUSHO */
+# endif /* FLUSHO */
 
 # if defined(VDISABLE) && !defined(_POSIX_VDISABLE)
 #  define _POSIX_VDISABLE VDISABLE
-# endif				/* VDISABLE && ! _POSIX_VDISABLE */
+# endif /* VDISABLE && ! _POSIX_VDISABLE */
 
 # ifndef _POSIX_VDISABLE
 #  define _POSIX_VDISABLE -1
-# endif				/* _POSIX_VDISABLE */
+# endif /* _POSIX_VDISABLE */
 
 /*
  * Work around ISC's definition of IEXTEN which is
  * XCASE!
  */
 # ifdef ISC
-#  ifdef IEXTEN
-#   undef IEXTEN
-#  endif				/* IEXTEN */
-#  define IEXTEN 0
-# endif				/* ISC */
-#endif				/* TERMIO || POSIX */
+#  if defined(IEXTEN) && defined(XCASE)
+#   if IEXTEN == XCASE
+#    undef IEXTEN
+#    define IEXTEN 0
+#   endif /* IEXTEN == XCASE */
+#  endif /* IEXTEN && XCASE */
+# endif /* ISC */
+
+#endif /* TERMIO || POSIX */
 
 
 /* ed.init.c -- init routines for the line editor */
@@ -135,10 +146,470 @@ extern bool GotTermCaps;
 static bool edit_discipline = 0;
 union txname tx_disc;
 extern char strPOSIX[];
-#endif				/* _IBMR2 */
+#endif /* _IBMR2 */
 
 static	int	dosetkey __P((char *, char *));
 
+static struct tcshtty {
+    char *t_name;
+    int  t_setmask;
+    int  t_clrmask;
+} ttylist[] = {
+
+#ifdef TERMIO
+# define M_INPUT	0
+    { "iflag:", ICRNL, (INLCR|IGNCR) },
+# define M_OUTPUT	1
+    { "oflag:", (OPOST|ONLCR), ONLRET },
+# define M_CONTROL	2
+    { "cflag:", 0, 0 },
+# define M_LINED	3
+    { "lflag:", (ISIG|ICANON|ECHO|ECHOE|ECHOCTL|IEXTEN),
+	        (NOFLSH|ECHONL|EXTPROC|FLUSHO) },
+
+#else /* GSTTY */
+
+# define M_CONTROL	0
+    { "", (ECHO|CRMOD|ANYP), (CBREAK|RAW|LCASE|VTDELAY|ALLDELAY) },
+# define M_LOCAL	1
+    { "", (LCRTBS|LCRTERA|LCRTKIL), (LPRTERA|LFLUSHO) },
+
+#endif /* TERMIO */
+};
+
+static struct tcshmodes {
+    char *m_name;
+    int   m_value;
+    int   m_type;
+} modelist[] = {
+#ifdef TERMIO
+
+# ifdef	IGNBRK
+    { "ignbrk",	IGNBRK,	M_INPUT },
+# endif /* IGNBRK */
+# ifdef	BRKINT
+    { "brkint",	BRKINT,	M_INPUT },
+# endif /* BRKINT */
+# ifdef	IGNPAR
+    { "ignpar",	IGNPAR,	M_INPUT },
+# endif /* IGNPAR */
+# ifdef	PARMRK
+    { "parmrk",	PARMRK,	M_INPUT },
+# endif /* PARMRK */
+# ifdef	INPCK
+    { "inpck",	INPCK,	M_INPUT },
+# endif /* INPCK */
+# ifdef	ISTRIP
+    { "istrip",	ISTRIP,	M_INPUT },
+# endif /* ISTRIP */
+# ifdef	INLCR
+    { "inlcr",	INLCR,	M_INPUT },
+# endif /* INLCR */
+# ifdef	IGNCR
+    { "igncr",	IGNCR,	M_INPUT },
+# endif /* IGNCR */
+# ifdef	ICRNL
+    { "icrnl",	ICRNL,	M_INPUT },
+# endif /* ICRNL */
+# ifdef	IUCLC
+    { "iuclc",	IUCLC,	M_INPUT },
+# endif /* IUCLC */
+# ifdef	IXON
+    { "ixon",	IXON,	M_INPUT },
+# endif /* IXON */
+# ifdef	IXANY
+    { "ixany",	IXANY,	M_INPUT },
+# endif /* IXANY */
+# ifdef	IXOFF
+    { "ixoff",	IXOFF,	M_INPUT },
+# endif /* IXOFF */
+# ifdef  IMAXBEL
+    { "imaxbel",IMAXBEL,M_INPUT },
+# endif /* IMAXBEL */
+
+# ifdef	OPOST
+    { "opost",	OPOST,	M_OUTPUT },
+# endif /* OPOST */
+# ifdef	OLCUC
+    { "olcuc",	OLCUC,	M_OUTPUT },
+# endif /* OLCUC */
+# ifdef	ONLCR
+    { "onlcr",	ONLCR,	M_OUTPUT },
+# endif /* ONLCR */
+# ifdef	OCRNL
+    { "ocrnl",	OCRNL,	M_OUTPUT },
+# endif /* OCRNL */
+# ifdef	ONOCR
+    { "onocr",	ONOCR,	M_OUTPUT },
+# endif /* ONOCR */
+# ifdef ONOEOT
+    { "onoeot",	ONOEOT,	M_OUTPUT },
+# endif /* ONOEOT */
+# ifdef	ONLRET
+    { "onlret",	ONLRET,	M_OUTPUT },
+# endif /* ONLRET */
+# ifdef	OFILL
+    { "ofill",	OFILL,	M_OUTPUT },
+# endif /* OFILL */
+# ifdef	OFDEL
+    { "ofdel",	OFDEL,	M_OUTPUT },
+# endif /* OFDEL */
+# ifdef	NLDLY
+    { "nldly",	NLDLY,	M_OUTPUT },
+# endif /* NLDLY */
+# ifdef	CRDLY
+    { "crdly",	CRDLY,	M_OUTPUT },
+# endif /* CRDLY */
+# ifdef	TABDLY
+    { "tabdly",	TABDLY,	M_OUTPUT },
+# endif /* TABDLY */
+# ifdef	XTABS
+    { "xtabs",	XTABS,	M_OUTPUT },
+# endif /* XTABS */
+# ifdef	BSDLY
+    { "bsdly",	BSDLY,	M_OUTPUT },
+# endif /* BSDLY */
+# ifdef	VTDLY
+    { "vtdly",	VTDLY,	M_OUTPUT },
+# endif /* VTDLY */
+# ifdef	FFDLY
+    { "ffdly",	FFDLY,	M_OUTPUT },
+# endif /* FFDLY */
+# ifdef	PAGEOUT
+    { "pageout",PAGEOUT,M_OUTPUT },
+# endif /* PAGEOUT */
+# ifdef	WRAP
+    { "wrap",	WRAP,	M_OUTPUT },
+# endif /* WRAP */
+
+# ifdef	CIGNORE
+    { "cignore",CIGNORE,M_CONTROL },
+# endif /* CBAUD */
+# ifdef	CBAUD
+    { "cbaud",	CBAUD,	M_CONTROL },
+# endif /* CBAUD */
+# ifdef	CSTOPB
+    { "cstopb",	CSTOPB,	M_CONTROL },
+# endif /* CSTOPB */
+# ifdef	CREAD
+    { "cread",	CREAD,	M_CONTROL },
+# endif /* CREAD */
+# ifdef	PARENB
+    { "parenb",	PARENB,	M_CONTROL },
+# endif /* PARENB */
+# ifdef	PARODD
+    { "parodd",	PARODD,	M_CONTROL },
+# endif /* PARODD */
+# ifdef	HUPCL
+    { "hupcl",	HUPCL,	M_CONTROL },
+# endif /* HUPCL */
+# ifdef	CLOCAL
+    { "clocal",	CLOCAL,	M_CONTROL },
+# endif /* CLOCAL */
+# ifdef	LOBLK
+    { "loblk",	LOBLK,	M_CONTROL },
+# endif /* LOBLK */
+# ifdef	CIBAUD
+    { "cibaud",	CIBAUD,	M_CONTROL },
+# endif /* CIBAUD */
+# ifdef CRTSCTS
+#  ifdef CCTS_OFLOW
+    { "ccts_oflow",CCTS_OFLOW,M_CONTROL },
+#  else
+    { "crtscts",CRTSCTS,M_CONTROL },
+#  endif /* CCTS_OFLOW */
+# endif /* CRTSCTS */
+# ifdef CRTS_IFLOW
+    { "crts_iflow",CRTS_IFLOW,M_CONTROL },
+# endif /* CRTS_IFLOW */
+# ifdef MDMBUF
+    { "mdmbuf",	MDMBUF,	M_CONTROL },
+# endif /* MDMBUF */
+
+# ifdef	ISIG
+    { "isig",	ISIG,	M_LINED },
+# endif /* ISIG */
+# ifdef	ICANON
+    { "icanon",	ICANON,	M_LINED },
+# endif /* ICANON */
+# ifdef	XCASE
+    { "xcase",	XCASE,	M_LINED },
+# endif /* XCASE */
+# ifdef	ECHO
+    { "echo",	ECHO,	M_LINED },
+# endif /* ECHO */
+# ifdef	ECHOE
+    { "echoe",	ECHOE,	M_LINED },
+# endif /* ECHOE */
+# ifdef	ECHOK
+    { "echok",	ECHOK,	M_LINED },
+# endif /* ECHOK */
+# ifdef	ECHONL
+    { "echonl",	ECHONL,	M_LINED },
+# endif /* ECHONL */
+# ifdef	NOFLSH
+    { "noflsh",	NOFLSH,	M_LINED },
+# endif /* NOFLSH */
+# ifdef	TOSTOP
+    { "tostop",	TOSTOP,	M_LINED },
+# endif /* TOSTOP */
+# ifdef	ECHOCTL
+    { "echoctl",ECHOCTL,M_LINED },
+# endif /* ECHOCTL */
+# ifdef	ECHOPRT
+    { "echoprt",ECHOPRT,M_LINED },
+# endif /* ECHOPRT */
+# ifdef	ECHOKE
+    { "echoke",	ECHOKE,	M_LINED },
+# endif /* ECHOKE */
+# ifdef	DEFECHO
+    { "defecho",DEFECHO,M_LINED },
+# endif /* DEFECHO */
+# ifdef	FLUSHO
+    { "flusho",	FLUSHO,	M_LINED },
+# endif /* FLUSHO */
+# ifdef	PENDIN
+    { "pendin",	PENDIN,	M_LINED },
+# endif /* PENDIN */
+# ifdef	IEXTEN
+    { "iexten",	IEXTEN,	M_LINED },
+# endif /* IEXTEN */
+# ifdef	NOKERNINFO
+    { "nokerninfo",NOKERNINFO,M_LINED },
+# endif /* NOKERNINFO */
+# ifdef	ALTWERASE
+    { "altwerase",ALTWERASE,M_LINED },
+# endif /* ALTWERASE */
+
+#else /* GSTTY */
+
+# ifdef	TANDEM
+    { "tandem",	TANDEM,	M_CONTROL },
+# endif /* TANDEM */
+# ifdef	CBREAK
+    { "cbreak",	CBREAK,	M_CONTROL },
+# endif /* CBREAK */
+# ifdef	LCASE
+    { "lcase",	LCASE,	M_CONTROL },
+# endif /* LCASE */
+# ifdef	ECHO
+    { "echo",	ECHO,	M_CONTROL },
+# endif /* ECHO */	
+# ifdef	CRMOD
+    { "crmod",	CRMOD,	M_CONTROL },
+# endif /* CRMOD */
+# ifdef	RAW
+    { "raw",	RAW,	M_CONTROL },
+# endif /* RAW */
+# ifdef	ODDP
+    { "oddp",	ODDP,	M_CONTROL },
+# endif /* ODDP */
+# ifdef	EVENP
+    { "evenp",	EVENP,	M_CONTROL },
+# endif /* EVENP */
+# ifdef	ANYP
+    { "anyp",	ANYP,	M_CONTROL },
+# endif /* ANYP */
+# ifdef	NLDELAY
+    { "nldelay",NLDELAY,M_CONTROL },
+# endif /* NLDELAY */
+# ifdef	TBDELAY
+    { "tbdelay",TBDELAY,M_CONTROL },
+# endif /* TBDELAY */
+# ifdef	XTABS
+    { "xtabs",	XTABS,	M_CONTROL },
+# endif /* XTABS */
+# ifdef	CRDELAY
+    { "crdelay",CRDELAY,M_CONTROL },
+# endif /* CRDELAY */
+# ifdef	VTDELAY
+    { "vtdelay",VTDELAY,M_CONTROL },
+# endif /* VTDELAY */
+# ifdef	BSDELAY
+    { "bsdelay",BSDELAY,M_CONTROL },
+# endif /* BSDELAY */
+# ifdef	CRTBS
+    { "crtbs",	CRTBS,	M_CONTROL },
+# endif /* CRTBS */
+# ifdef	PRTERA
+    { "prtera",	PRTERA,	M_CONTROL },
+# endif /* PRTERA */
+# ifdef	CRTERA
+    { "crtera",	CRTERA,	M_CONTROL },
+# endif /* CRTERA */
+# ifdef	TILDE
+    { "tilde",	TILDE,	M_CONTROL },
+# endif /* TILDE */
+# ifdef	MDMBUF
+    { "mdmbuf",	MDMBUF,	M_CONTROL },
+# endif /* MDMBUF */
+# ifdef	LITOUT
+    { "litout",	LITOUT,	M_CONTROL },
+# endif /* LITOUT */
+# ifdef	TOSTOP
+    { "tostop",	TOSTOP,	M_CONTROL },
+# endif /* TOSTOP */
+# ifdef	FLUSHO
+    { "flusho",	FLUSHO,	M_CONTROL },
+# endif /* FLUSHO */
+# ifdef	NOHANG
+    { "nohang",	NOHANG,	M_CONTROL },
+# endif /* NOHANG */
+# ifdef	L001000
+    { "l001000",L001000,M_CONTROL },
+# endif /* L001000 */
+# ifdef	CRTKIL
+    { "crtkil",	CRTKIL,	M_CONTROL },
+# endif /* CRTKIL */
+# ifdef	PASS8
+    { "pass8",	PASS8,	M_CONTROL },
+# endif /* PASS8 */
+# ifdef	CTLECH
+    { "ctlech",	CTLECH,	M_CONTROL },
+# endif /* CTLECH */
+# ifdef	PENDIN
+    { "pendin",	PENDIN,	M_CONTROL },
+# endif /* PENDIN */
+# ifdef	DECCTQ
+    { "decctq",	DECCTQ,	M_CONTROL },
+# endif /* DECCTQ */
+# ifdef	NOFLSH
+    { "noflsh",	NOFLSH,	M_CONTROL },
+# endif /* NOFLSH */
+
+# ifdef	LCRTBS
+    { "lcrtbs",	LCRTBS,	M_LOCAL },
+# endif /* LCRTBS */
+# ifdef	LPRTERA
+    { "lprtera",LPRTERA,M_LOCAL },
+# endif /* LPRTERA */
+# ifdef	LCRTERA
+    { "lcrtera",LCRTERA,M_LOCAL },
+# endif /* LCRTERA */
+# ifdef	LTILDE
+    { "ltilde",	LTILDE,	M_LOCAL },
+# endif /* LTILDE */
+# ifdef	LMDMBUF
+    { "lmdmbuf",LMDMBUF,M_LOCAL },
+# endif /* LMDMBUF */
+# ifdef	LLITOUT
+    { "llitout",LLITOUT,M_LOCAL },
+# endif /* LLITOUT */
+# ifdef	LTOSTOP
+    { "ltostop",LTOSTOP,M_LOCAL },
+# endif /* LTOSTOP */
+# ifdef	LFLUSHO
+    { "lflusho",LFLUSHO,M_LOCAL },
+# endif /* LFLUSHO */
+# ifdef	LNOHANG
+    { "lnohang",LNOHANG,M_LOCAL },
+# endif /* LNOHANG */
+# ifdef	LCRTKIL
+    { "lcrtkil",LCRTKIL,M_LOCAL },
+# endif /* LCRTKIL */
+# ifdef	LPASS8
+    { "lpass8",	LPASS8,	M_LOCAL },
+# endif /* LPASS8 */	
+# ifdef	LCTLECH
+    { "lctlech",LCTLECH,M_LOCAL },
+# endif /* LCTLECH */
+# ifdef	LPENDIN
+    { "lpendin",LPENDIN,M_LOCAL },
+# endif /* LPENDIN */
+# ifdef	LDECCTQ
+    { "ldecctq",LDECCTQ,M_LOCAL },
+# endif /* LDECCTQ */
+# ifdef	LNOFLSH
+    { "lnoflsh",LNOFLSH,M_LOCAL },
+# endif /* LNOFLSH */
+
+#endif /* TERMIO */
+    { NULL, 0, -1 },
+};
+
+
+void
+dosetty(v, t)
+    Char **v;
+    struct command *t;
+{
+    struct tcshmodes *m;
+    char x, *d;
+    int aflag = 0;
+    Char *s;
+
+    setname(short2str(*v++));
+
+    if (v && *v && v[0][0] == '-' && v[0][1] == 'a' && v[0][2] == '\0') {
+	aflag = 1;
+	v++;
+    }
+    if (!v || !*v) {
+	int i = -1;
+	int len = 0, st = 0, cu;
+	for (m = modelist; m->m_name; m++) {
+	    if (m->m_type != i) {
+		xprintf("%s%s", i != -1 ? "\n" : "", 
+			ttylist[m->m_type].t_name);
+		i = m->m_type;
+		st = len = strlen(ttylist[m->m_type].t_name);
+	    }
+
+	    x = (ttylist[i].t_setmask & m->m_value) ? '+' : '\0';
+	    x = (ttylist[i].t_clrmask & m->m_value) ? '-' : x;
+
+	    if (x != '\0' || aflag) {
+		cu = strlen(m->m_name) + (x != '\0') + 1;
+		if (len + cu >= T_Cols) {
+		    xprintf("\n%*s", st, "");
+		    len = st + cu;
+		}
+		else 
+		    len += cu;
+		if (x != '\0')
+		    xprintf("%c%s ", x, m->m_name);
+		else
+		    xprintf("%s ", m->m_name);
+	    }
+	}
+	xprintf("\n");
+	return;
+    }
+    while (v && (s = *v++)) {
+	switch (*s) {
+	case '+':
+	case '-':
+	    x = *s++;
+	    break;
+	default:
+	    x = '\0';
+	    break;
+	}
+	d = short2str(s);
+	for (m = modelist; m->m_name; m++)
+	    if (strcmp(m->m_name, d) == 0)
+		break;
+	if (!m->m_name) 
+	    stderror(ERR_NAME | ERR_SYSTEM, d, "Invalid argument");
+
+	switch (x) {
+	case '+':
+	    ttylist[m->m_type].t_setmask |= m->m_value;
+	    ttylist[m->m_type].t_clrmask &= ~m->m_value;
+	    break;
+	case '-':
+	    ttylist[m->m_type].t_setmask &= ~m->m_value;
+	    ttylist[m->m_type].t_clrmask |= m->m_value;
+	    break;
+	default:
+	    ttylist[m->m_type].t_setmask &= ~m->m_value;
+	    ttylist[m->m_type].t_clrmask &= ~m->m_value;
+	    break;
+	}
+    }
+} /* end dosetty */
+
+
 #ifdef SIG_WINDOW
 void
 check_window_size(force)
@@ -146,7 +617,7 @@ check_window_size(force)
 {
 #ifdef BSDSIGS
     sigmask_t omask;
-#endif				/* BSDSIGS */
+#endif /* BSDSIGS */
     int     lins, cols;
 
     /* don't want to confuse things here */
@@ -154,7 +625,7 @@ check_window_size(force)
     omask = sigblock(sigmask(SIG_WINDOW)) & ~sigmask(SIG_WINDOW);
 #else				/* BSDSIGS */
     (void) sighold(SIG_WINDOW);
-#endif				/* BSDSIGS */
+#endif /* BSDSIGS */
 
     /*
      * From: bret@shark.agps.lanl.gov (Bret Thaeler) Avoid sunview bug, where a
@@ -178,7 +649,7 @@ check_window_size(force)
     (void) sigsetmask(omask);	/* can change it again */
 #else				/* BSDSIGS */
     (void) sigrelse(SIG_WINDOW);
-#endif				/* BSDSIGS */
+#endif /* BSDSIGS */
 }
 
 sigret_t
@@ -194,19 +665,19 @@ int snum;
     check_window_size(0);
 #ifndef SIGVOID
     return (snum);
-#endif
+#endif 
 }
 
-#endif				/* SIG_WINDOW */
+#endif /* SIG_WINDOW */
 
 /* LPASS8 is new in 4.3, and makes cbreak mode provide all 8 bits.  */
 #ifndef LPASS8
 # define LPASS8 0		/* we don't have it.  Too bad!! */
-#endif
+#endif 
 
 #ifndef CTRL
 # define	CTRL(c)	('c'&037)
-#endif
+#endif 
 
 void
 ed_set_tty_eight_bit()
@@ -216,26 +687,26 @@ ed_set_tty_eight_bit()
     struct termio ttynio;
 # else				/* GSTTY */
     int     ttynlb;
-# endif				/* TERMIO */
+# endif /* TERMIO */
 #else				/* POSIX */
     struct termios ttynio;
-#endif				/* POSIX */
+#endif /* POSIX */
 
 #ifndef POSIX
 # ifdef TERMIO
     (void) ioctl(SHIN, TCGETA, (ioctl_t) & ttynio);
 # else				/* GSTTY */
     (void) ioctl(SHIN, TIOCLGET, (ioctl_t) & ttynlb);
-# endif				/* TERMIO */
+# endif /* TERMIO */
 #else				/* POSIX */
     (void) tcgetattr(SHIN, &ttynio);
-#endif				/* POSIX */
+#endif /* POSIX */
 
 #if defined(TERMIO) || defined(POSIX)
     Tty_eight_bit = (ttynio.c_cflag & CSIZE) == CS8;
 #else				/* GSTTY */
     Tty_eight_bit = ttynlb & (LPASS8 | LLITOUT);
-#endif
+#endif 
 }
 
 void
@@ -249,7 +720,7 @@ ed_Init()
 
 #ifdef DEBUG_EDIT
     CheckMaps();		/* do a little error checking on key maps */
-#endif
+#endif 
 
     if (!havesetup) {		/* if we have never been called */
 	replacemode = 0;	/* start out in insert mode */
@@ -264,7 +735,7 @@ ed_Init()
 	T_Speed = nio.c_cflag & CBAUD;
 #  else
 	T_Speed = 0;
-#  endif
+#  endif 
 # else				/* GSTTY */
 	(void) ioctl(SHIN, TIOCGETP, (ioctl_t) & nb);	/* normal setup */
 	xb = nb;		/* new setup */
@@ -275,15 +746,15 @@ ed_Init()
 #  ifdef TIOCGPAGE
 	(void) ioctl(SHIN, TIOCGPAGE, (ioctl_t) & npc);
 	xpc = npc;
-#  endif				/* TIOCGPAGE */
+#  endif /* TIOCGPAGE */
 	(void) ioctl(SHIN, TIOCLGET, (ioctl_t) & nlb);
 	xlb = nlb;
 	T_Speed = nb.sg_ispeed;
-# endif				/* TERMIO */
+# endif /* TERMIO */
 #else				/* POSIX */
 	(void) tcgetattr(SHIN, &nio);
 	T_Speed = cfgetispeed(&nio);
-#endif				/* POSIX */
+#endif /* POSIX */
 
 #if defined(TERMIO) || defined(POSIX)
 	xio = nio;
@@ -295,6 +766,7 @@ ed_Init()
 	    T_Tabs = 1;
 	}
 
+#ifdef notdef
 	nio.c_iflag &= ~(INLCR | IGNCR);
 	nio.c_iflag |= (ICRNL);
 
@@ -303,10 +775,22 @@ ed_Init()
 	/* don't muck with c_cflag */
 	nio.c_lflag &= ~(NOFLSH | ECHOK | ECHONL | EXTPROC | FLUSHO);
 	nio.c_lflag |= (ISIG | ICANON | ECHO | ECHOE | ECHOCTL | IEXTEN);
+#endif 
+	nio.c_iflag &= ~ttylist[M_INPUT].t_clrmask;
+	nio.c_iflag |=  ttylist[M_INPUT].t_setmask;
+
+	nio.c_oflag &= ~ttylist[M_OUTPUT].t_clrmask;
+	nio.c_oflag |=  ttylist[M_OUTPUT].t_setmask;
+
+	nio.c_cflag &= ~ttylist[M_CONTROL].t_clrmask;
+	nio.c_cflag |=  ttylist[M_CONTROL].t_setmask;
+
+	nio.c_lflag &= ~ttylist[M_LINED].t_clrmask;
+	nio.c_lflag |=  ttylist[M_LINED].t_setmask;
 
 # ifdef IRIX3_3
 	nio.c_line = NTTYDISC;
-# endif				/* IRIX3_3 */
+# endif /* IRIX3_3 */
 	nio.c_cc[VINTR] = '\003';	/* ^C */
 	nio.c_cc[VQUIT] = '\034';	/* ^\ */
 	nio.c_cc[VERASE] = '\177';	/* ^? */
@@ -315,45 +799,48 @@ ed_Init()
 	nio.c_cc[VEOL] = _POSIX_VDISABLE;
 # ifdef VEOL2
 	nio.c_cc[VEOL2] = _POSIX_VDISABLE;
-# endif
+# endif 
 # ifdef VSWTCH
 	nio.c_cc[VSWTCH] = _POSIX_VDISABLE;
-# endif				/* VSWTCH */
+# endif /* VSWTCH */
+# ifdef VERASE2
+	nio.c_cc[VERASE2] = _POSIX_VDISABLE;
+# endif /* VERASE2 */
 # ifdef VSTART
 	nio.c_cc[VSTART] = '\021';	/* ^Q */
-# endif				/* VSTART */
+# endif /* VSTART */
 # ifdef VSTOP
 	nio.c_cc[VSTOP] = '\023';	/* ^S */
-# endif				/* VSTOP */
+# endif /* VSTOP */
 # ifdef VWERASE
 	nio.c_cc[VWERASE] = '\027';	/* ^W */
-# endif				/* VWERASE */
+# endif /* VWERASE */
 # ifdef VSUSP
 	nio.c_cc[VSUSP] = CSUSP;
-# endif
+# endif 
 # ifdef VDSUSP
 	nio.c_cc[VDSUSP] = '\031';	/* ^Y */
-# endif				/* VDSUSP */
+# endif /* VDSUSP */
 # ifdef VREPRINT
 	nio.c_cc[VREPRINT] = '\022';	/* ^R */
-# endif				/* WREPRINT */
+# endif /* WREPRINT */
 # ifdef VDISCARD
 	nio.c_cc[VDISCARD] = '\017';	/* ^O */
-# endif				/* VDISCARD */
+# endif /* VDISCARD */
 # ifdef VLNEXT
 	nio.c_cc[VLNEXT] = '\026';	/* ^V */
-# endif				/* VLNEXT */
+# endif /* VLNEXT */
 # ifdef VSTATUS
 	nio.c_cc[VSTATUS] = '\024';	/* ^T */
-# endif				/* VSTATUS */
+# endif /* VSTATUS */
 # ifdef VPGOFF
 	nio.c_cc[VPGOFF] = ' ';	/* " " */
-# endif				/* VPGOFF */
+# endif /* VPGOFF */
 # ifdef VPAGE
 	nio.c_cc[VPAGE] = '\015';	/* ^M */
-# endif				/* VPAGE */
+# endif /* VPAGE */
 
-# if defined(OREO) || defined(hpux) || defined(_IBMR2)
+# if (defined(OREO) || defined(hpux) || defined(_IBMR2)) && !defined(hp9000s500)
 
 	(void) ioctl(SHIN, TIOCGLTC, (ioctl_t) & nlc);
 	xlc = nlc;
@@ -361,7 +848,7 @@ ed_Init()
 	nlc.t_suspc = nio.c_cc[VSUSP];	/* stop process signal	 */
 #  else
 	nlc.t_suspc = '\032';	/* stop process signal	 */
-#  endif
+#  endif 
 	nlc.t_dsuspc = '\031';	/* delayed stop process signal */
 #  ifdef hpux
 	/*
@@ -376,11 +863,11 @@ ed_Init()
 	nlc.t_flushc = '\017';	/* flush output (toggles) */
 	nlc.t_werasc = '\027';	/* word erase */
 	nlc.t_lnextc = '\026';	/* literal next character */
-#  endif				/* hpux */
-# endif				/* OREO || hpux || _IBMR2 */
+#  endif /* hpux */
+# endif /* OREO || hpux || _IBMR2 */
 # ifdef SIG_WINDOW
 	(void) sigset(SIG_WINDOW, window_change);	/* for window systems */
-# endif
+# endif 
 #else	/* GSTTY */		/* V7, Berkeley style tty */
 
 
@@ -392,15 +879,27 @@ ed_Init()
 	}
 
 	if (T_Tabs) {		/* order of &= and |= is important to XTABS */
+#ifdef notdef
 	    nb.sg_flags &= ~(CBREAK | RAW | LCASE | XTABS | VTDELAY | ALLDELAY);
 	    nb.sg_flags |= (ECHO | CRMOD | ANYP);
+#endif 
+	    nb.sg_flags &= ~(ttylist[M_CONTROL].t_clrmask | XTABS);
+	    nb.sg_flags |=  ttylist[M_CONTROL].t_setmask;
 	}
 	else {
+#ifdef notdef
 	    nb.sg_flags &= ~(CBREAK | RAW | LCASE | VTDELAY | ALLDELAY);
 	    nb.sg_flags |= (ECHO | CRMOD | XTABS | ANYP);
+#endif 
+	    nb.sg_flags &= ~ttylist[M_CONTROL].t_clrmask;
+	    nb.sg_flags |=  (ttylist[M_CONTROL].t_setmask | XTABS);
 	}
+#ifdef notdef
 	nlb &= ~(LPRTERA);	/* let 8-bit mode stand as set */
 	nlb |= (LCRTBS | LCRTERA | LCRTKIL);
+#endif 
+	nlb &= ~ttylist[M_LOCAL].t_clrmask;
+	nlb |=  ttylist[M_LOCAL].t_setmask;
 
 	nb.sg_erase = '\177';	/* del prev. char == DEL */
 	nb.sg_kill = '\025';	/* special case of del region */
@@ -415,7 +914,7 @@ ed_Init()
 	ntc.t_brkc = '\0';	/* input delimiter (like nl) */
 # else
 	ntc.t_brkc = -1;	/* input delimiter (like nl) */
-# endif
+# endif 
 
 	nlc.t_suspc = '\032';	/* stop process signal	 */
 	nlc.t_dsuspc = '\031';	/* delayed stop process signal	 */
@@ -431,12 +930,12 @@ ed_Init()
 	npc.tps_pagec = '\040';	/* show next page " " */
 	npc.tps_pgoffc = '\015';/* Ignore paging until input ^M */
 	npc.tps_flag = 0;
-# endif				/* TIOCGPAGE */
+# endif /* TIOCGPAGE */
 
 # ifdef SIG_WINDOW
 	(void) sigset(SIG_WINDOW, window_change);	/* for window systems */
-# endif
-#endif				/* TERMIO */
+# endif 
+#endif /* TERMIO */
     }
 
     /*
@@ -464,7 +963,7 @@ ed_Init()
 
 # ifdef IRIX3_3
     xio.c_line = NTTYDISC;
-# endif				/* IRIX3_3 */
+# endif /* IRIX3_3 */
     xio.c_cc[VINTR] = '\003';	/* ^C */
     xio.c_cc[VQUIT] = '\034';	/* ^\ */
     xio.c_cc[VERASE] = '\177';	/* ^? */
@@ -473,45 +972,45 @@ ed_Init()
     xio.c_cc[VTIME] = 0;	/* don't time out */
 # ifdef VEOL2
     xio.c_cc[VEOL2] = _POSIX_VDISABLE;
-# endif				/* VEOL2 */
+# endif /* VEOL2 */
 # ifdef VSWTCH
     xio.c_cc[VSWTCH] = _POSIX_VDISABLE;
-# endif				/* VSWTCH */
+# endif /* VSWTCH */
 # ifdef VSTART
     xio.c_cc[VSTART] = '\021';	/* ^Q */
-# endif				/* VSTART */
+# endif /* VSTART */
 # ifdef VSTOP
     xio.c_cc[VSTOP] = '\023';	/* ^S */
-# endif				/* VSTOP */
+# endif /* VSTOP */
 # ifdef VWERASE
     xio.c_cc[VWERASE] = _POSIX_VDISABLE;
-# endif				/* VWERASE */
+# endif /* VWERASE */
 # ifdef VSUSP
     xio.c_cc[VSUSP] = _POSIX_VDISABLE;
-# endif				/* VSUSP */
+# endif /* VSUSP */
 # ifdef VDSUSP
     xio.c_cc[VDSUSP] = _POSIX_VDISABLE;
-# endif				/* VDSUSP */
+# endif /* VDSUSP */
 # ifdef VREPRINT
     xio.c_cc[VREPRINT] = _POSIX_VDISABLE;
-# endif				/* VREPRINT */
+# endif /* VREPRINT */
 # ifdef VDISCARD
     xio.c_cc[VDISCARD] = '\017';/* ^O */
-# endif				/* VDISCARD */
+# endif /* VDISCARD */
 # ifdef VLNEXT
     xio.c_cc[VLNEXT] = _POSIX_VDISABLE;
-# endif				/* VLNEXT */
+# endif /* VLNEXT */
 # ifdef VSTATUS
     xio.c_cc[VSTATUS] = '\024';	/* ^T */
-# endif				/* VSTATUS */
+# endif /* VSTATUS */
 # ifdef VPGOFF
     xio.c_cc[VPGOFF] = ' ';	/* " " */
-# endif				/* VPGOFF */
+# endif /* VPGOFF */
 # ifdef VPAGE
     xio.c_cc[VPAGE] = '\015';	/* ^M */
-# endif				/* VPAGE */
+# endif /* VPAGE */
 
-# if defined(OREO) || defined(hpux) || defined(_IBMR2)
+# if (defined(OREO) || defined(hpux) || defined(_IBMR2)) && !defined(hp9000s500)
 #  ifdef VSUSP
     xlc.t_suspc = xio.c_cc[VSUSP];	/* stop process signal	 */
 #  else
@@ -532,7 +1031,7 @@ ed_Init()
     xlc.t_werasc = _POSIX_VDISABLE;	/* word erase */
     xlc.t_lnextc = _POSIX_VDISABLE;	/* literal next character */
 #  endif /* hpux */
-# endif	/* OREO || hpux || _IBMR2 */
+# endif /* OREO || hpux || _IBMR2 */
 #else /* GSTTY */
     if (T_Tabs) {		/* order of &= and |= is important to XTABS */
 	xb.sg_flags &= ~(RAW | ECHO | LCASE | XTABS | VTDELAY | ALLDELAY);
@@ -557,7 +1056,7 @@ ed_Init()
     xtc.t_brkc = '\0';		/* input delimiter (like nl) */
 # else
     xtc.t_brkc = -1;		/* input delimiter (like nl) */
-# endif
+# endif 
 
     xlc.t_suspc = -1;		/* stop process signal (was CTRL(z)) */
     xlc.t_dsuspc = -1;		/* delayed stop process signal	 */
@@ -573,12 +1072,12 @@ ed_Init()
     xpc.tps_pagec = -1;		/* disable show next page */
     xpc.tps_pgoffc = -1;	/* disable Ignore paging until input */
     xpc.tps_flag = 0;
-# endif				/* TIOCGPAGE */
+# endif /* TIOCGPAGE */
 
     xlb &= ~LPRTERA;
     xlb |= (LCRTBS | LCRTERA | LCRTKIL);
     Tty_eight_bit = nlb & (LPASS8 | LLITOUT);
-#endif				/* TERMIO || POSIX */
+#endif /* TERMIO || POSIX */
     havesetup = 1;
 
     /* Make sure the tty has a well-defined initial state */
@@ -621,7 +1120,7 @@ Rawmode()
 	if (ioctl(FSHTTY, TXSETLD, (ioctl_t) strPOSIX) < 0)
 	    return (-1);
     }
-#endif				/* _IBMR2 */
+#endif /* _IBMR2 */
 
 #ifndef POSIX
 # ifdef TERMIO
@@ -631,16 +1130,19 @@ Rawmode()
     if (ioctl(SHIN, TIOCGETP, (ioctl_t) & testsgb) < 0)
 	return (-1);		/* SHIN has been closed */
     /* test the normal flags */
-# endif				/* TERMIO */
+# endif /* TERMIO */
 #else				/* POSIX */
     if (tcgetattr(SHIN, &testio) < 0)
 	return (-1);		/* SHIN has been closed */
-#endif				/* POSIX */
+#endif /* POSIX */
 
 #if defined(POSIX) || defined(TERMIO)
     Tty_eight_bit = (testio.c_cflag & CSIZE) == CS8;
     if (testio.c_cflag != nio.c_cflag) { 
 	nio.c_cflag = testio.c_cflag;
+	nio.c_cflag &= ~ttylist[M_CONTROL].t_clrmask;
+	nio.c_cflag |=  ttylist[M_CONTROL].t_setmask;
+
 	xio.c_cflag = testio.c_cflag;
     }
 # ifdef POSIX
@@ -667,10 +1169,14 @@ Rawmode()
 
     if ((testio.c_lflag != nio.c_lflag) &&
 	(testio.c_lflag != xio.c_lflag)) {
-	/* Christos: There was and ifdef here that would set ECHONL!?? */
 	nio.c_lflag = testio.c_lflag;
+#ifdef notdef
 	nio.c_lflag &= ~(NOFLSH | ECHOK | ECHONL | EXTPROC | FLUSHO);
 	nio.c_lflag |= (ISIG | ICANON | IEXTEN | ECHO | ECHOE | ECHOCTL);
+#endif 
+	nio.c_lflag &= ~ttylist[M_LINED].t_clrmask;
+	nio.c_lflag |=  ttylist[M_LINED].t_setmask;
+
 	xio.c_lflag = testio.c_lflag;
 	/* don't mask out ECHOE cause programs need it */
 	xio.c_lflag &= ~(NOFLSH | ICANON | IEXTEN | ECHO | ECHOK |
@@ -681,8 +1187,13 @@ Rawmode()
     if ((testio.c_iflag != nio.c_iflag) &&
 	(testio.c_iflag != xio.c_iflag)) {
 	nio.c_iflag = testio.c_iflag;
+#ifdef notdef
 	nio.c_iflag &= ~(INLCR | IGNCR);
 	nio.c_iflag |= (ICRNL);
+#endif 
+	nio.c_iflag &= ~ttylist[M_INPUT].t_clrmask;
+	nio.c_iflag |=  ttylist[M_INPUT].t_setmask;
+
 	xio.c_iflag = testio.c_iflag;
 	xio.c_iflag &= ~(INLCR | IGNCR);
 	xio.c_iflag |= (ICRNL);
@@ -692,8 +1203,13 @@ Rawmode()
 	(testio.c_oflag != xio.c_oflag)) {
 	/* Christos: There was and ifdef here that would set ONLRET!?? */
 	nio.c_oflag = testio.c_oflag;
+#ifdef notdef
 	nio.c_oflag &= ~(ONLRET);
 	nio.c_oflag |= (OPOST | ONLCR);
+#endif 
+	nio.c_oflag &= ~ttylist[M_OUTPUT].t_clrmask;
+	nio.c_oflag |=  ttylist[M_OUTPUT].t_setmask;
+
 	xio.c_oflag = testio.c_oflag;
 	xio.c_oflag &= ~(ONLRET);
 	xio.c_oflag |= (OPOST | ONLCR);
@@ -725,59 +1241,59 @@ Rawmode()
     if (dosetkey((char *) &testio.c_cc[VSWTCH], (char *) &nio.c_cc[VSWTCH]))
 	(void) dosetkey((char *) &testio.c_cc[VSWTCH],
 			(char *) &xio.c_cc[VSWTCH]);
-# endif				/* VSWTCH */
+# endif /* VSWTCH */
 # ifdef VEOL2
     if (dosetkey((char *) &testio.c_cc[VEOL2], (char *) &nio.c_cc[VEOL2]))
 	(void) dosetkey((char *) &testio.c_cc[VEOL2], 
 			(char *) &xio.c_cc[VEOL2]);
-# endif				/* VEOL2 */
+# endif /* VEOL2 */
 # ifdef VSTART
     if (dosetkey((char *) &testio.c_cc[VSTART], (char *) &nio.c_cc[VSTART]))
 	(void) dosetkey((char *) &testio.c_cc[VSTART],
 			(char *) &xio.c_cc[VSTART]);
-# endif				/* VSTART */
+# endif /* VSTART */
 # ifdef VSTOP
     if (dosetkey((char *) &testio.c_cc[VSTOP], (char *) &nio.c_cc[VSTOP]))
 	(void) dosetkey((char *) &testio.c_cc[VSTOP], 
 			(char *) &xio.c_cc[VSTOP]);
-# endif				/* VSTOP */
+# endif /* VSTOP */
 # ifdef VWERASE
     (void) dosetkey((char *) &testio.c_cc[VWERASE], 
 		    (char *) &nio.c_cc[VWERASE]);
-# endif				/* VWERASE */
+# endif /* VWERASE */
 # ifdef VREPRINT
     (void) dosetkey((char *) &testio.c_cc[VREPRINT],
 		    (char *) &nio.c_cc[VREPRINT]);
-# endif				/* VREPRINT */
+# endif /* VREPRINT */
 # ifdef VSUSP
     (void) dosetkey((char *) &testio.c_cc[VSUSP], (char *) &nio.c_cc[VSUSP]);
-# endif				/* VSUSP */
+# endif /* VSUSP */
 # ifdef VDSUSP
     (void) dosetkey((char *) &testio.c_cc[VDSUSP], (char *) &nio.c_cc[VDSUSP]);
-# endif				/* VDSUSP */
+# endif /* VDSUSP */
 # ifdef VLNEXT
     (void) dosetkey((char *) &testio.c_cc[VLNEXT], (char *) &nio.c_cc[VLNEXT]);
-# endif				/* VLNEXT */
+# endif /* VLNEXT */
 # ifdef VDISCARD
     if (dosetkey((char *) &testio.c_cc[VDISCARD], (char *) &nio.c_cc[VDISCARD]))
 	(void) dosetkey((char *) &testio.c_cc[VDISCARD],
 			(char *) &xio.c_cc[VDISCARD]);
-# endif				/* VDISCARD */
+# endif /* VDISCARD */
 # ifdef VSTATUS
     if (dosetkey((char *) &testio.c_cc[VSTATUS], (char *) &nio.c_cc[VSTATUS]))
 	(void) dosetkey((char *) &testio.c_cc[VSTATUS],
 			(char *) &xio.c_cc[VSTATUS]);
-# endif				/* VSTATUS */
+# endif /* VSTATUS */
 # ifdef VPGOFF
     if (dosetkey((char *) &testio.c_cc[VPGOFF], (char *) &nio.c_cc[VPGOFF]))
 	(void) dosetkey((char *) &testio.c_cc[VPGOFF],
 			(char *) &xio.c_cc[VPGOFF]);
-# endif				/* VPGOFF */
+# endif /* VPGOFF */
 # ifdef VPAGE
     if (dosetkey((char *) &testio.c_cc[VPAGE], (char *) &nio.c_cc[VPAGE]))
 	(void) dosetkey((char *) &testio.c_cc[VPAGE],
 			(char *) &xio.c_cc[VPAGE]);
-# endif				/* VPAGE */
+# endif /* VPAGE */
 
 # ifndef POSIX
     if (ioctl(SHIN, TCSETAW, (ioctl_t) & xio) < 0)
@@ -785,15 +1301,15 @@ Rawmode()
 # else /* POSIX */
     if (tcsetattr(SHIN, TCSADRAIN, &xio) < 0)
 	return (-1);
-# endif	/* POSIX */
+# endif /* POSIX */
 
-# if defined(OREO) || defined(hpux) || defined(_IBMR2)
+# if (defined(OREO) || defined(hpux) || defined(_IBMR2)) && !defined(hp9000s500)
     /* get and set the new local chars */
     if (ioctl(SHIN, TIOCGLTC, (ioctl_t) & testlc) < 0)
 	return (-1);
 #ifdef VSUSP
     testlc.t_suspc = nio.c_cc[VSUSP];	/* stop process signal	 */
-#endif
+#endif 
     (void) dosetkey((char *) &testlc.t_suspc, (char *) &nlc.t_suspc);
     (void) dosetkey((char *) &testlc.t_dsuspc, (char *) &nlc.t_dsuspc);
 # ifndef hpux
@@ -805,7 +1321,7 @@ Rawmode()
 # endif /* hpux */
     if (ioctl(SHIN, TIOCSLTC, (ioctl_t) & xlc) < 0)
 	return (-1);
-# endif	/* OREO || hpux || _IBMR2 */
+# endif /* OREO || hpux || _IBMR2 */
 
 #else /* GSTTY */		/* for BSD... */
 
@@ -864,8 +1380,13 @@ Rawmode()
 	    T_Tabs = CanWeTab();
 	}
 
+#ifdef notdef
 	nb.sg_flags &= ~(CBREAK | RAW | LCASE | VTDELAY | ALLDELAY);
 	nb.sg_flags |= (ECHO | CRMOD | ANYP);
+#endif 
+	nb.sg_flags &= ~ttylist[M_CONTROL].t_clrmask;
+	nb.sg_flags |=  ttylist[M_CONTROL].t_setmask;
+
 	if (T_Tabs) {		/* order of &= and |= is important to XTABS */
 	    nb.sg_flags &= ~XTABS;
 	}
@@ -891,8 +1412,12 @@ Rawmode()
  * Montreal (Qc) Canada H3C 3J7		  <bur%iro.udem.cdn@ubc.csnet>
  * Thanks!
  */
+#ifdef notdef
 	nlb &= ~(LPRTERA | LFLUSHO);
 	nlb |= (LCRTBS | LCRTERA | LCRTKIL);
+#endif 
+	nlb &= ~ttylist[M_LOCAL].t_clrmask;
+	nlb |=  ttylist[M_LOCAL].t_setmask;
 
 	xlb = nlb;
     }
@@ -906,7 +1431,7 @@ Rawmode()
     (void) dosetkey((char *) &testpc.tps_statc, (char *) &npc.tps_statc);
     (void) dosetkey((char *) &testpc.tps_pagec, (char *) &npc.tps_pagec);
     (void) dosetkey((char *) &testpc.tps_pgoffc, (char *) &npc.tps_pgoffc);
-# endif				/* TIOCGPAGE */
+# endif /* TIOCGPAGE */
 
     (void) dosetkey((char *) &testlc.t_suspc, (char *) &nlc.t_suspc);
     (void) dosetkey((char *) &testlc.t_dsuspc, (char *) &nlc.t_dsuspc);
@@ -925,10 +1450,10 @@ Rawmode()
 # ifdef TIOCGPAGE
     if (ioctl(SHIN, TIOCSPAGE, (ioctl_t) & xpc) < 0)
 	return (-1);
-# endif				/* TIOCGPAGE */
+# endif /* TIOCGPAGE */
     if (ioctl(SHIN, TIOCLSET, (ioctl_t) & xlb) < 0)
 	return (-1);
-# endif				/* TERMIO || POSIX */
+# endif /* TERMIO || POSIX */
     Tty_raw_mode = 1;
     flush();			/* flush any buffered output */
     return (0);
@@ -945,7 +1470,7 @@ Cookedmode()
 	    return (-1);
 	edit_discipline = 0;
     }
-#endif				/* _IBMR2 */
+#endif /* _IBMR2 */
     if (!Tty_raw_mode)
 	return (0);
 
@@ -953,15 +1478,15 @@ Cookedmode()
     orig_intr = signal(SIGINT, SIG_IGN);	/* hold this for reseting tty */
 #else
     orig_intr = sigset(SIGINT, SIG_IGN);	/* hold this for reseting tty */
-#endif				/* BSDSIGS */
+#endif /* BSDSIGS */
 #ifndef POSIX
 # ifdef TERMIO
     if (ioctl(SHIN, TCSETAW, (ioctl_t) & nio) < 0)
 	return (-1);
-#  if defined(OREO) || defined(hpux) || defined(_IBMR2)
+# if (defined(OREO) || defined(hpux) || defined(_IBMR2)) && !defined(hp9000s500)
     if (ioctl(SHIN, TIOCSLTC, (ioctl_t) & nlc) < 0)
 	return (-1);
-#  endif				/* OREO || hpux || _IBMR2 */
+#  endif /* OREO || hpux || _IBMR2 */
 # else	/* GSTTY */		/* for BSD... */
     if (ioctl(SHIN, TIOCSETN, (ioctl_t) & nb) < 0)
 	return (-1);
@@ -972,24 +1497,24 @@ Cookedmode()
 # ifdef TIOCGPAGE
     if (ioctl(SHIN, TIOCSPAGE, (ioctl_t) & npc) < 0)
 	return (-1);
-# endif				/* TIOCGPAGE */
+# endif /* TIOCGPAGE */
     if (ioctl(SHIN, TIOCLSET, (ioctl_t) & nlb) < 0)
 	return (-1);
-# endif				/* TERMIO */
+# endif /* TERMIO */
 #else				/* POSIX */
     if (tcsetattr(SHIN, TCSADRAIN, &nio) < 0)
 	return (-1);
 # if defined(OREO) || defined(hpux) || defined(_IBMR2)
     if (ioctl(SHIN, TIOCSLTC, (ioctl_t) & nlc) < 0)
 	return (-1);
-# endif				/* OREO || hpux || _IBMR2 */
-#endif				/* POSIX */
+# endif /* OREO || hpux || _IBMR2 */
+#endif /* POSIX */
     Tty_raw_mode = 0;
 #ifdef BSDSIGS
     (void) signal(SIGINT, orig_intr);	/* take these again */
 #else
     (void) sigset(SIGINT, orig_intr);	/* take these again */
-#endif				/* BSDSIGS */
+#endif /* BSDSIGS */
     return (0);
 }
 
@@ -1008,7 +1533,7 @@ ResetInLine()
     Argument = 1;
 #ifdef notdef
     LastKill = KillBuf;		/* no kill buffer */
-#endif
+#endif 
     LastCmd = F_UNASSIGNED;	/* previous command executed */
     MacroLvl = -1;		/* no currently active macros */
 }
@@ -1038,7 +1563,7 @@ Load_input_line()
 	    PushMacro(Input_Line);
 	}
     }
-#endif
+#endif 
     return chrs > 0;
 }
 
@@ -1060,10 +1585,10 @@ QuoteModeOn()
     struct sgttyb rawb;
 # else
     struct termio rawb;
-# endif				/* TERMIO */
+# endif /* TERMIO */
 #else				/* POSIX */
     struct termios rawb;
-#endif				/* POSIX */
+#endif /* POSIX */
 
     if (MacroLvl >= 0)
 	return;
@@ -1078,7 +1603,7 @@ QuoteModeOn()
 # else				/* POSIX */
     if (tcsetattr(SHIN, TCSADRAIN, &rawb) < 0)
 	return;
-# endif				/* POSIX */
+# endif /* POSIX */
 #else				/* GSTTYB */
 
     rawb = xb;
@@ -1086,7 +1611,7 @@ QuoteModeOn()
     rawb.sg_flags |= RAW;
     if (ioctl(SHIN, TIOCSETN, (ioctl_t) & rawb) < 0)
 	return;
-#endif				/* TERMIO || POSIX */
+#endif /* TERMIO || POSIX */
     Tty_quote_mode = 1;
     return;
 }
@@ -1104,10 +1629,10 @@ QuoteModeOff()
 # else				/* POSIX */
     if (tcsetattr(SHIN, TCSADRAIN, &xio) < 0)
 	return;
-# endif				/* POSIX */
+# endif /* POSIX */
 #else				/* GSTTYB */
     if (ioctl(SHIN, TIOCSETN, (ioctl_t) & xb) < 0)
 	return;
-#endif				/* !TERMIO && !POSIX */
+#endif /* !TERMIO && !POSIX */
     return;
 }
