@@ -1,4 +1,4 @@
-/* $Header: /home/hyperion/mu/christos/src/sys/tcsh-6.00/RCS/tc.sched.c,v 3.2 1991/07/15 19:37:24 christos Exp $ */
+/* $Header: /home/hyperion/mu/christos/src/sys/tcsh-6.00/RCS/tc.sched.c,v 3.3 1991/07/17 13:24:11 christos Exp $ */
 /*
  * tc.sched.c: Scheduled command execution
  *
@@ -37,7 +37,7 @@
  * SUCH DAMAGE.
  */
 #include "config.h"
-RCSID("$Id: tc.sched.c,v 3.2 1991/07/15 19:37:24 christos Exp $")
+RCSID("$Id: tc.sched.c,v 3.3 1991/07/17 13:24:11 christos Exp $")
 
 #include "sh.h"
 #include "ed.h"
@@ -47,7 +47,7 @@ extern int just_signaled;
 
 struct sched_event {
     struct sched_event *t_next;
-    long    t_when;
+    time_t t_when;
     Char  **t_lex;
 };
 static struct sched_event *sched_ptr = NULL;
