@@ -1,4 +1,4 @@
-/* $Header: /home/hyperion/mu/christos/src/sys/tcsh-6.00/RCS/tc.vers.c,v 3.1 1991/07/15 19:37:24 christos Exp $ */
+/* $Header: /home/hyperion/mu/christos/src/sys/tcsh-6.00/RCS/tc.vers.c,v 3.5 1991/08/06 01:50:07 christos Exp $ */
 /*
  * tc.vers.c: Version dependent stuff
  */
@@ -35,7 +35,7 @@
  * SUCH DAMAGE.
  */
 #include "config.h"
-RCSID("$Id: tc.vers.c,v 3.1 1991/07/15 19:37:24 christos Exp $")
+RCSID("$Id: tc.vers.c,v 3.5 1991/08/06 01:50:07 christos Exp $")
 
 #include "sh.h"
 #include "patchlevel.h"
@@ -141,6 +141,10 @@ gethosttype()
    hosttype = str2short("hp9000s300");
 #  endif /* hp9000s300 */
 #  ifndef _havehosttype_
+# if defined(hp9000s500) && !defined(_havehosttype_)
+#  define _havehosttype_
+   hosttype = str2short("hp9000s500");
+# endif /* hp9000s500 */
 #   define _havehosttype_
    hosttype = str2short("hp");
 #  endif /* _havehosttype_ */
@@ -172,10 +176,34 @@ gethosttype()
 # endif /* u3b2 */
 
 # if defined(i386) && SVID > 0
-#  define _havehosttype_
-    hosttype = str2short("iAPX386");
+
+#  if !defined(_havehosttype_) && (defined(ISC) || defined(ISC202))
+#   define _havehosttype_
+    hosttype = str2short("isc386");
+#  endif /* !_havehosttype_ && (ISC || ISC202) */
+
+#  if !defined(_havehosttype_) && defined(SCO)
+#   define _havehosttype_
+    hosttype = str2short("sco386");
+#  endif /* !_havehosttype_ && SCO */
+
+#  if !defined(_havehosttype_) && defined(INTEL)
+#   define _havehosttype_
+    hosttype = str2short("intel386");
+#  endif /* !_havehosttype_ && INTEL */
+
+#  ifndef _havehosttype_
+#   define _havehosttype_
+    hosttype = str2short("i386");
+#  endif /* _havehosttype_ */
+
 # endif 
 
+#ifdef UNIXPC
+# define _havehosttype_
+    hosttype = str2short("unixpc");
+#endif /* UNIXPC/att3b1/att7300 */
+
 # ifdef alliant
 #  define _havehosttype_
     hosttype = str2short("alliant");	/* for Alliant FX Series */
@@ -208,6 +236,7 @@ gethosttype()
 #  endif 
 # else /* !sequent */
 #  ifdef ns32000
+#   define _havehosttype_
 #   ifdef CMUCS			/* hack for Mach (in the true spirit of CMU) */
     hosttype = str2short("multimax");
 #   else /* CMUCS */
@@ -314,6 +343,11 @@ gethosttype()
 #  endif
 # endif /* sgi */
 
+#ifdef uts
+# define _havehosttype_
+    hosttype = str2short("amdahl");
+#endif /* uts */
+  
 
 # ifndef _havehosttype_
 #  define _havehosttype_
